-- *********************************************************************
-- Update Database Script
-- *********************************************************************
-- Change Log: changelog/db-changelog-master.xml
-- Ran at: 2/21/22, 1:01 PM
-- Against: config@offline:postgresql?changeLogFile=target/databasechangelog.csv&outputLiquibaseSql=true
-- Liquibase version: 4.7.1
-- *********************************************************************

CREATE TABLE databasechangelog (ID VARCHAR(255) NOT NULL, AUTHOR VARCHAR(255) NOT NULL, FILENAME VARCHAR(255) NOT NULL, DATEEXECUTED TIMESTAMP WITHOUT TIME ZONE NOT NULL, ORDEREXECUTED INTEGER NOT NULL, EXECTYPE VARCHAR(10) NOT NULL, MD5SUM VARCHAR(35), DESCRIPTION VARCHAR(255), COMMENTS VARCHAR(255), TAG VARCHAR(255), LIQUIBASE VARCHAR(20), CONTEXTS VARCHAR(255), LABELS VARCHAR(255), DEPLOYMENT_ID VARCHAR(10));

-- Changeset schema/tables/modules.xml::modules-01::marche
CREATE TABLE modules (module_id BIGINT NOT NULL, module_name VARCHAR(500) NOT NULL, jms_queue VARCHAR(500), CONSTRAINT modules_pk PRIMARY KEY (module_id));

COMMENT ON TABLE modules IS 'Know modules table.';

COMMENT ON COLUMN modules.module_name IS 'Module name.';

COMMENT ON COLUMN modules.jms_queue IS 'Last known JMS queue for this module.';

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('modules-01', 'marche', 'schema/tables/modules.xml', NOW(), 1, '8:58cd8c155672ce7203f35dbe76f3dd6c', 'createTable tableName=modules', '', 'EXECUTED', NULL, NULL, '4.7.1', '5444901116');

-- Changeset schema/tables/modules.xml::drop jms_queue column::marche
ALTER TABLE modules DROP COLUMN jms_queue;

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('drop jms_queue column', 'marche', 'schema/tables/modules.xml', NOW(), 3, '8:f834e64dd09d3583ff7492a7208db122', 'dropColumn columnName=jms_queue, tableName=modules', '', 'EXECUTED', NULL, NULL, '4.7.1', '5444901116');

-- Changeset schema/tables/modules.xml::set module_name unique::osdjup
ALTER TABLE modules ADD UNIQUE (module_name);

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('set module_name unique', 'osdjup', 'schema/tables/modules.xml', NOW(), 5, '8:62f9a43d060c167fb3138078ba885a3d', 'addUniqueConstraint tableName=modules', '', 'EXECUTED', NULL, NULL, '4.7.1', '5444901116');

-- Changeset schema/tables/settings.xml::settings-01::marche
CREATE TABLE settings (setting_id BIGINT NOT NULL, setting_key VARCHAR(500) NOT NULL, setting_value VARCHAR(4000) NOT NULL, setting_module_id BIGINT, global BOOLEAN, CONSTRAINT setting_pk PRIMARY KEY (setting_id));

COMMENT ON TABLE settings IS 'Settings stored as key/value pairs.';

COMMENT ON COLUMN settings.setting_key IS 'Setting key.';

COMMENT ON COLUMN settings.setting_value IS 'Setting value.';

COMMENT ON COLUMN settings.setting_module_id IS 'Module of setting. Global if null.';

COMMENT ON COLUMN settings.global IS 'True if the setting is global.';

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('settings-01', 'marche', 'schema/tables/settings.xml', NOW(), 7, '8:ebfd23402f25ffdeef87db789bf0e470', 'createTable tableName=settings', '', 'EXECUTED', NULL, NULL, '4.7.1', '5444901116');

-- Changeset schema/tables/settings.xml::settings_module_fk-01::marche
ALTER TABLE settings ADD CONSTRAINT fk_settings_module FOREIGN KEY (setting_module_id) REFERENCES modules (module_id);

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('settings_module_fk-01', 'marche', 'schema/tables/settings.xml', NOW(), 9, '8:c28ca57473d87133dbf9199d55f492b7', 'addForeignKeyConstraint baseTableName=settings, constraintName=fk_settings_module, referencedTableName=modules', '', 'EXECUTED', NULL, NULL, '4.7.1', '5444901116');

-- Changeset schema/tables/settings.xml::Add description column.::marche
ALTER TABLE settings ADD setting_description VARCHAR(500) DEFAULT '-' NOT NULL;

COMMENT ON COLUMN settings.setting_description IS 'Setting description.';

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('Add description column.', 'marche', 'schema/tables/settings.xml', NOW(), 11, '8:467333de59810060103919ebdd353232', 'addColumn tableName=settings', '', 'EXECUTED', NULL, NULL, '4.7.1', '5444901116');

-- Changeset schema/tables/settings.xml::addUniqueConstraint-module-key::marche
ALTER TABLE settings ADD UNIQUE (setting_key, setting_module_id);

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('addUniqueConstraint-module-key', 'marche', 'schema/tables/settings.xml', NOW(), 13, '8:75d0688b4273f3428b0210764effd063', 'addUniqueConstraint tableName=settings', '', 'EXECUTED', NULL, NULL, '4.7.1', '5444901116');

-- Changeset schema/tables/settings.xml::last modified column::marche
ALTER TABLE settings ADD setting_last_modified TIMESTAMP with time zone;

COMMENT ON COLUMN settings.setting_last_modified IS 'Date and time of last modification.';

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('last modified column', 'marche', 'schema/tables/settings.xml', NOW(), 15, '8:9f084302cf23553ad45e9b0414b7fdbe', 'addColumn tableName=settings', '', 'EXECUTED', NULL, NULL, '4.7.1', '5444901116');

-- Changeset schema/tables/settings.xml::Add updated by column.::nhily
ALTER TABLE settings ADD updated_by VARCHAR(60);

COMMENT ON COLUMN settings.updated_by IS 'Setting updated by user.';

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('Add updated by column.', 'nhily', 'schema/tables/settings.xml', NOW(), 17, '8:252116f229cabad245a5d3dd50396702', 'addColumn tableName=settings', '', 'EXECUTED', NULL, NULL, '4.7.1', '5444901116');

-- Changeset schema/tables/settings.xml::Add seq for module id::nhily
CREATE SEQUENCE  IF NOT EXISTS HIBERNATE_SEQUENCE START WITH 50;

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('Add seq for module id', 'nhily', 'schema/tables/settings.xml', NOW(), 19, '8:abaef8ae815818826a991a9b8aab0d94', 'createSequence sequenceName=HIBERNATE_SEQUENCE', '', 'EXECUTED', NULL, NULL, '4.7.1', '5444901116');

-- Changeset schema/tables/parameter.xml::create paremeter table::andtho
CREATE TABLE parameter (param_id VARCHAR(500) NOT NULL, param_description VARCHAR(500) NOT NULL, param_value VARCHAR(4000), CONSTRAINT param_pk PRIMARY KEY (param_id));

COMMENT ON TABLE parameter IS 'Table as a placeholder of parameters and its values';

COMMENT ON COLUMN parameter.param_id IS 'Id and code for parameter.';

COMMENT ON COLUMN parameter.param_description IS 'Description of parameter or value.';

COMMENT ON COLUMN parameter.param_value IS 'Parameter value.';

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('create paremeter table', 'andtho', 'schema/tables/parameter.xml', NOW(), 21, '8:b092ef33e5d314da2e782e5383c142cf', 'createTable tableName=parameter', '', 'EXECUTED', NULL, NULL, '4.7.1', '5444901116');

-- Changeset schema/initdata/globalSettings.xml::globalSettings-01::marche
INSERT INTO settings (setting_id, setting_key, setting_value, global, setting_description, setting_last_modified, updated_by) VALUES ('1', 'measurementSystem', 'metric', '1', 'Choise of metric system, typically metric or imperial.', NOW(), 'UVMS');

INSERT INTO settings (setting_id, setting_key, setting_value, global, setting_description, setting_last_modified, updated_by) VALUES ('2', 'coordinateFormat', 'degreesMinutesSeconds', '1', 'Coordinate system.', NOW(), 'UVMS');

INSERT INTO settings (setting_id, setting_key, setting_value, global, setting_description, setting_last_modified, updated_by) VALUES ('3', 'dateTimeFormat', 'YYYY-MM-DD HH:mm:ss', '1', 'Choice of datetime format.', NOW(), 'UVMS');

INSERT INTO settings (setting_id, setting_key, setting_value, global, setting_description, setting_last_modified, updated_by) VALUES ('4', 'defaultHomePage', 'reporting', '1', 'Default home page.', NOW(), 'UVMS');

INSERT INTO settings (setting_id, setting_key, setting_value, global, setting_description, setting_last_modified, updated_by) VALUES ('5', 'availableLanguages', 'en-gb', '1', 'List of available language codes, comma-separated.', NOW(), 'UVMS');

INSERT INTO settings (setting_id, setting_key, setting_value, global, setting_description, setting_last_modified, updated_by) VALUES ('6', 'distanceUnit', 'nm', '1', 'Unit used for distances.', NOW(), 'UVMS');

INSERT INTO settings (setting_id, setting_key, setting_value, global, setting_description, setting_last_modified, updated_by) VALUES ('7', 'speedUnit', 'kts', '1', 'Unit used for speed.', NOW(), 'UVMS');

INSERT INTO settings (setting_id, setting_key, setting_value, global, setting_description, setting_last_modified, updated_by) VALUES ('8', 'maxSpeed', '15', '1', 'Maximum allowed speed, measured in nautical miles.', NOW(), 'UVMS');

INSERT INTO settings (setting_id, setting_key, setting_value, global, setting_description, setting_last_modified, updated_by) VALUES ('9', 'timezone', '0', '1', 'Global timezone (offset from UTC in minutes).', NOW(), 'UVMS');

INSERT INTO settings (setting_id, setting_key, setting_value, global, setting_description, setting_last_modified, updated_by) VALUES ('100', 'headerTemplate', 'default', '1', 'Header template frontend', NOW(), 'UVMS');

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('globalSettings-01', 'marche', 'schema/initdata/globalSettings.xml', NOW(), 23, '8:544a19c8ce04f06d135e88be8ea9c94d', 'insert tableName=settings; insert tableName=settings; insert tableName=settings; insert tableName=settings; insert tableName=settings; insert tableName=settings; insert tableName=settings; insert tableName=settings; insert tableName=settings; inse...', '', 'EXECUTED', NULL, NULL, '4.7.1', '5444901116');

-- Changeset schema/initdata/globalSettings.xml::add_global_setting_flux_local_nation_code::stihft
INSERT INTO settings (setting_id, setting_key, setting_value, global, setting_description, setting_last_modified, updated_by) VALUES ('10', 'flux_local_nation_code', 'TODO_UPDATE__FLUX_LOCAL_NATION_CODE', '1', 'The nation code of the country where this instance of UnionVMS is deployed.', NOW(), 'UVMS');

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('add_global_setting_flux_local_nation_code', 'stihft', 'schema/initdata/globalSettings.xml', NOW(), 25, '8:795d2a2afa86078f1cd78ec1326203eb', 'insert tableName=settings', '', 'EXECUTED', NULL, NULL, '4.7.1', '5444901116');

-- Changeset schema/initdata/globalSettings.xml::add_global_setting_currency::stihft
INSERT INTO settings (setting_id, setting_key, setting_value, global, setting_description, setting_last_modified, updated_by) VALUES ('11', 'currency', 'EUR', '1', 'The currency of the country where the software is deployed. In ISO 4217 format.', NOW(), 'UVMS');

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('add_global_setting_currency', 'stihft', 'schema/initdata/globalSettings.xml', NOW(), 27, '8:a34f01fcf8adf70d8b274c073e5a7dda', 'insert tableName=settings', '', 'EXECUTED', NULL, NULL, '4.7.1', '5444901116');

-- Changeset schema/initdata/globalSettings.xml::add_global_setting_flux_nodes::stihft
INSERT INTO settings (setting_id, setting_key, setting_value, global, setting_description, setting_last_modified, updated_by) VALUES ('12', 'flux_nodes', 'BGR:EAFA,CPV,CYP:ERS,CYP:FMC,DEU,DNK,ESP,EST,FIN,FRA:DEVELOPPEMENT-DURABLE:DAM,GBR,GRC:FA,HRV:FISHERIES,IRL:AGRI,IRL:FMC:VMS,ITA,ITA:FMC:GUARDIACOSTIERA:ROME,LTU,LVA:ZM,NLD:VIR,POL,PRT:DGRM:MAIN,SWE,XFA,XMO,XNW', '1', 'A list of FLUX nodes', NOW(), 'UVMS');

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('add_global_setting_flux_nodes', 'stihft', 'schema/initdata/globalSettings.xml', NOW(), 29, '8:4428317e71fa11ef798deca04d0fd02b', 'insert tableName=settings', '', 'EXECUTED', NULL, NULL, '4.7.1', '5444901116');

-- Changeset changelog/v4.3.6/db-changelog-recreate-hibernate-sequence.xml::recreate hibernate sequence::peerik
DROP SEQUENCE HIBERNATE_SEQUENCE CASCADE;

CREATE SEQUENCE  IF NOT EXISTS HIBERNATE_SEQUENCE START WITH 150;

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('recreate hibernate sequence', 'peerik', 'changelog/v4.3.6/db-changelog-recreate-hibernate-sequence.xml', NOW(), 31, '8:ee003176e4ee1eb0beb465d89760da8c', 'dropSequence sequenceName=HIBERNATE_SEQUENCE; createSequence sequenceName=HIBERNATE_SEQUENCE', '', 'EXECUTED', NULL, NULL, '4.7.1', '5444901116');

