CREATE TABLE databasechangelog (ID VARCHAR(255) NOT NULL, AUTHOR VARCHAR(255) NOT NULL, FILENAME VARCHAR(255) NOT NULL, DATEEXECUTED TIMESTAMP WITHOUT TIME ZONE NOT NULL, ORDEREXECUTED INTEGER NOT NULL, EXECTYPE VARCHAR(10) NOT NULL, MD5SUM VARCHAR(35), DESCRIPTION VARCHAR(255), COMMENTS VARCHAR(255), TAG VARCHAR(255), LIQUIBASE VARCHAR(20), CONTEXTS VARCHAR(255), LABELS VARCHAR(255), DEPLOYMENT_ID VARCHAR(10));

-- *********************************************************************
-- Update Database Script
-- *********************************************************************
-- Change Log: changelog/db-changelog-master.xml
-- Ran at: 9/5/24, 9:23 AM
-- Against: exchange@offline:postgresql?changeLogFile=target/databasechangelog.csv&outputLiquibaseSql=true
-- Liquibase version: 4.29.1
-- *********************************************************************

-- Changeset schema/tables/parameter.xml::create paremeter table::jojoha
CREATE TABLE parameter (param_id VARCHAR(500) NOT NULL, param_description VARCHAR(500) NOT NULL, param_value VARCHAR(4000), CONSTRAINT param_pk PRIMARY KEY (param_id));

COMMENT ON TABLE parameter IS 'Table as a placeholder of parameters and its values';

COMMENT ON COLUMN parameter.param_id IS 'Id and code for parameter.';

COMMENT ON COLUMN parameter.param_description IS 'Description of parameter or value.';

COMMENT ON COLUMN parameter.param_value IS 'Parameter value.';

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('create paremeter table', 'jojoha', 'schema/tables/parameter.xml', NOW(), 1, '9:c75dc2e8df8d4182be550d5854bae310', 'createTable tableName=parameter', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/serviceregistry.xml::create service registry table::andtho
CREATE TABLE service (serv_id UUID NOT NULL, serv_serviceclassname VARCHAR(500), serv_name VARCHAR(100), serv_serviceresponse VARCHAR(500), serv_desc VARCHAR(200), serv_active BOOLEAN, serv_type VARCHAR(50) NOT NULL, serv_sat_type VARCHAR(50), serv_status BOOLEAN, serv_updatetime TIMESTAMP with time zone NOT NULL, serv_upuser VARCHAR(60) NOT NULL, CONSTRAINT servreg_pk PRIMARY KEY (serv_id), UNIQUE (serv_serviceclassname), UNIQUE (serv_name), UNIQUE (serv_serviceresponse));

COMMENT ON TABLE service IS 'Table containing list of plugins';

COMMENT ON COLUMN service.serv_id IS 'Id and code for parameter.';

COMMENT ON COLUMN service.serv_serviceclassname IS 'Fully qualified name of service.';

COMMENT ON COLUMN service.serv_name IS 'Service display name.';

COMMENT ON COLUMN service.serv_serviceresponse IS 'The response topic message.';

COMMENT ON COLUMN service.serv_desc IS 'Service description.';

COMMENT ON COLUMN service.serv_active IS 'If the service is active.';

COMMENT ON COLUMN service.serv_type IS 'Type of service.';

COMMENT ON COLUMN service.serv_sat_type IS 'Type of service satellite.';

COMMENT ON COLUMN service.serv_status IS 'Status of service. Stands for STARTED/STOPPED';

COMMENT ON COLUMN service.serv_updatetime IS 'Last updated date time.';

COMMENT ON COLUMN service.serv_upuser IS 'Last update userid.';

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('create service registry table', 'andtho', 'schema/tables/serviceregistry.xml', NOW(), 3, '9:1bc517695470fb70d758d95c0dec763d', 'createTable tableName=service', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/servicecapability.xml::table for linking a service with capabilities::johlyn
CREATE TABLE service_capability (servcap_id UUID NOT NULL, servcap_serv_id UUID NOT NULL, servcap_capability VARCHAR(25) NOT NULL, servcap_value BOOLEAN NOT NULL, servcap_updatetime TIMESTAMP with time zone NOT NULL, servcap_upuser VARCHAR(60) NOT NULL, CONSTRAINT servcap_pk PRIMARY KEY (servcap_id));

COMMENT ON TABLE service_capability IS 'Table for linking a plugin with capabilities';

COMMENT ON COLUMN service_capability.servcap_id IS 'Id and code for table';

COMMENT ON COLUMN service_capability.servcap_serv_id IS 'Foreign key to the plugin service.';

COMMENT ON COLUMN service_capability.servcap_capability IS 'Capability';

COMMENT ON COLUMN service_capability.servcap_value IS 'Value of capability';

COMMENT ON COLUMN service_capability.servcap_updatetime IS 'Last updated date time.';

COMMENT ON COLUMN service_capability.servcap_upuser IS 'Last update userid.';

ALTER TABLE service_capability ADD CONSTRAINT servcap_serv_fk FOREIGN KEY (servcap_serv_id) REFERENCES service (serv_id);

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('table for linking a service with capabilities', 'johlyn', 'schema/tables/servicecapability.xml', NOW(), 5, '9:254d3b12ad53f03dfac6da58e7c7f6ab', 'createTable tableName=service_capability; addForeignKeyConstraint baseTableName=service_capability, constraintName=servcap_serv_fk, referencedTableName=service', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/servicecapability.xml::addIndexOnColumnServcap_serv_id::stihft
CREATE INDEX service_capability_i_1 ON service_capability(servcap_serv_id);

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('addIndexOnColumnServcap_serv_id', 'stihft', 'schema/tables/servicecapability.xml', NOW(), 7, '9:9c57f87fa4648b650c4b211084f5d4da', 'createIndex indexName=service_capability_i_1, tableName=service_capability', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/servicesetting.xml::table for linking a service with settings::jojoha
CREATE TABLE service_setting (servset_id UUID NOT NULL, servset_serv_id UUID NOT NULL, servset_setting VARCHAR(500) NOT NULL, servset_value VARCHAR(4000) NOT NULL, servset_updatetime TIMESTAMP with time zone NOT NULL, servset_upuser VARCHAR(60) NOT NULL, CONSTRAINT servset_pk PRIMARY KEY (servset_id));

COMMENT ON TABLE service_setting IS 'Table for linking a plugin service with settings';

COMMENT ON COLUMN service_setting.servset_id IS 'Id and code for table';

COMMENT ON COLUMN service_setting.servset_serv_id IS 'Foreign key to the plugin service.';

COMMENT ON COLUMN service_setting.servset_setting IS 'The setting key';

COMMENT ON COLUMN service_setting.servset_value IS 'The value of the setting';

COMMENT ON COLUMN service_setting.servset_updatetime IS 'Last updated date time.';

COMMENT ON COLUMN service_setting.servset_upuser IS 'Last update userid.';

ALTER TABLE service_setting ADD CONSTRAINT serv_fk FOREIGN KEY (servset_serv_id) REFERENCES service (serv_id);

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('table for linking a service with settings', 'jojoha', 'schema/tables/servicesetting.xml', NOW(), 9, '9:5cd2bc7e50d7fc0eb6504e6e43240d3b', 'createTable tableName=service_setting; addForeignKeyConstraint baseTableName=service_setting, constraintName=serv_fk, referencedTableName=service', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/servicesetting.xml::addIndexOnColumnServset_serv_id::stihft
CREATE INDEX service_setting_i_1 ON service_setting(servset_serv_id);

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('addIndexOnColumnServset_serv_id', 'stihft', 'schema/tables/servicesetting.xml', NOW(), 11, '9:f3652b23aae1155abbe66e02a6c45b5a', 'createIndex indexName=service_setting_i_1, tableName=service_setting', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/exchangelog.xml::create the exchange log table::johlyn
CREATE TABLE log (log_id UUID NOT NULL, log_type_ref_guid UUID, log_type_ref_type VARCHAR(25), log_senderreceiver VARCHAR(50) NOT NULL, log_daterecieved TIMESTAMP with time zone NOT NULL, log_status VARCHAR(50) NOT NULL, log_updatetime TIMESTAMP WITHOUT TIME ZONE NOT NULL, log_upuser VARCHAR(60) NOT NULL, log_type VARCHAR(25) NOT NULL, log_transfer_incoming BOOLEAN, log_source VARCHAR(50), log_fwdrule VARCHAR(50), log_recipient VARCHAR(50), log_fwddate TIMESTAMP WITH TIME ZONE, CONSTRAINT log_pk PRIMARY KEY (log_id));

COMMENT ON TABLE log IS 'Table containing the exchange logs in the exchange module';

COMMENT ON COLUMN log.log_id IS 'Auto id';

COMMENT ON COLUMN log.log_type_ref_guid IS 'id for message causing the log';

COMMENT ON COLUMN log.log_type_ref_type IS 'type of message causing the log';

COMMENT ON COLUMN log.log_senderreceiver IS 'The sender or receiver of the message logged';

COMMENT ON COLUMN log.log_daterecieved IS 'The date the message recieved in exchange';

COMMENT ON COLUMN log.log_status IS 'The status of the report';

COMMENT ON COLUMN log.log_updatetime IS 'Last updated date time.';

COMMENT ON COLUMN log.log_upuser IS 'Last update userid.';

COMMENT ON COLUMN log.log_type IS 'Type of log';

COMMENT ON COLUMN log.log_transfer_incoming IS 'Transfer type, incoming or outgoing';

COMMENT ON COLUMN log.log_source IS 'source of movement received';

COMMENT ON COLUMN log.log_fwdrule IS 'rule of send movement';

COMMENT ON COLUMN log.log_recipient IS 'recipient (flagstate) of send movement';

COMMENT ON COLUMN log.log_fwddate IS 'date of send movement';

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('create the exchange log table', 'johlyn', 'schema/tables/exchangelog.xml', NOW(), 13, '9:da2ce89bce008850fbbf70d87d2b7827', 'createTable tableName=log', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/exchangelog.xml::Add hibernate seq::nhily
CREATE SEQUENCE  IF NOT EXISTS HIBERNATE_SEQUENCE START WITH 100;

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('Add hibernate seq', 'nhily', 'schema/tables/exchangelog.xml', NOW(), 15, '9:30dd2d1d4c5c546aa2ac8b2015d55f1d', 'createSequence sequenceName=HIBERNATE_SEQUENCE', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/exchangelog.xml::Add column containing the incoming/outgoing message::stihft
ALTER TABLE log ADD log_type_ref_message TEXT;

COMMENT ON COLUMN log.log_type_ref_message IS 'The incoming/outgoing message';

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('Add column containing the incoming/outgoing message', 'stihft', 'schema/tables/exchangelog.xml', NOW(), 17, '9:128880ddd71596b342475927093424e9', 'addColumn tableName=log', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/exchangelog.xml::Add column containing the destination of the message::stihft
ALTER TABLE log ADD log_destination VARCHAR(50);

COMMENT ON COLUMN log.log_destination IS 'The destination of the message';

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('Add column containing the destination of the message', 'stihft', 'schema/tables/exchangelog.xml', NOW(), 19, '9:8e82174823282c3ecbe70a9ef6d03899', 'addColumn tableName=log', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/exchangelog.xml::Add column for duplicated messages::emrinalgr
ALTER TABLE log ADD duplicate BOOLEAN DEFAULT FALSE;

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('Add column for duplicated messages', 'emrinalgr', 'schema/tables/exchangelog.xml', NOW(), 21, '9:dd0f651d0b3a3a01f8488fd9808af5e9', 'addColumn tableName=log', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/exchangelogstatus.xml::create the exchange log table::johlyn
CREATE TABLE log_status (logstatus_id UUID NOT NULL, logstatus_status VARCHAR(50) NOT NULL, logstatus_timestamp TIMESTAMP with time zone NOT NULL, logstatus_log_id UUID NOT NULL, logstatus_updatetime TIMESTAMP with time zone NOT NULL, logstatus_upuser VARCHAR(60) NOT NULL, CONSTRAINT log_status_pk PRIMARY KEY (logstatus_id));

COMMENT ON TABLE log_status IS 'Table containing the exchange logs in the exchange module';

COMMENT ON COLUMN log_status.logstatus_id IS 'Auto id';

COMMENT ON COLUMN log_status.logstatus_status IS 'The status of the report';

COMMENT ON COLUMN log_status.logstatus_timestamp IS 'Timestamp for status.';

COMMENT ON COLUMN log_status.logstatus_log_id IS 'Fk to log table.';

COMMENT ON COLUMN log_status.logstatus_updatetime IS 'Last updated date time.';

COMMENT ON COLUMN log_status.logstatus_upuser IS 'Last update userid.';

ALTER TABLE log_status ADD CONSTRAINT log_status_log_fk FOREIGN KEY (logstatus_log_id) REFERENCES log (log_id);

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('create the exchange log table', 'johlyn', 'schema/tables/exchangelogstatus.xml', NOW(), 23, '9:da5a58e4629a18227f27e4a3ff7eeb6d', 'createTable tableName=log_status; addForeignKeyConstraint baseTableName=log_status, constraintName=log_status_log_fk, referencedTableName=log', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/exchangelogstatus.xml::addIndexOnColumnLogstatus_log_id::stihft
CREATE INDEX log_status_i_1 ON log_status(logstatus_log_id);

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('addIndexOnColumnLogstatus_log_id', 'stihft', 'schema/tables/exchangelogstatus.xml', NOW(), 25, '9:8011c9248f218d8c5b45fce10c8cf91a', 'createIndex indexName=log_status_i_1, tableName=log_status', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/unsentmessage.xml::unsent message::johlyn
CREATE TABLE unsent_message (unsent_guid UUID NOT NULL, unsent_message TEXT NOT NULL, unsent_senderreceiver VARCHAR(100), unsent_recipient VARCHAR(100), unsent_datereceived TIMESTAMP with time zone NOT NULL, unsent_updatetime TIMESTAMP with time zone NOT NULL, unsent_upuser VARCHAR(60) NOT NULL, unsent_function VARCHAR(60), CONSTRAINT unsent_pk PRIMARY KEY (unsent_guid));

COMMENT ON TABLE unsent_message IS 'Table containing the unsent messages in exchange module';

COMMENT ON COLUMN unsent_message.unsent_guid IS 'the id (guid) of the message';

COMMENT ON COLUMN unsent_message.unsent_message IS 'The unsent message';

COMMENT ON COLUMN unsent_message.unsent_senderreceiver IS 'Receiver of the unsent message';

COMMENT ON COLUMN unsent_message.unsent_recipient IS 'Recipient of the unsent message';

COMMENT ON COLUMN unsent_message.unsent_datereceived IS 'DateReceived of the unsent message';

COMMENT ON COLUMN unsent_message.unsent_updatetime IS 'Last updated date time.';

COMMENT ON COLUMN unsent_message.unsent_upuser IS 'Last update userid.';

COMMENT ON COLUMN unsent_message.unsent_function IS 'Called function.';

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('unsent message', 'johlyn', 'schema/tables/unsentmessage.xml', NOW(), 27, '9:5a134c08507dd0b2db6cc31aed3816c6', 'createTable tableName=unsent_message', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/unsentmessageproperty.xml::table for linking a service with settings::nhily
CREATE TABLE unsent_message_property (unsentprop_id UUID NOT NULL, unsentprop_unsent_id UUID, unsentprop_key VARCHAR(50), unsentprop_value VARCHAR(400), CONSTRAINT unsentprop_pk PRIMARY KEY (unsentprop_id));

COMMENT ON TABLE unsent_message_property IS 'Table for linking a plugin service with settings';

COMMENT ON COLUMN unsent_message_property.unsentprop_id IS 'Id and code for table';

COMMENT ON COLUMN unsent_message_property.unsentprop_unsent_id IS 'Foreign key to the plugin service.';

COMMENT ON COLUMN unsent_message_property.unsentprop_key IS 'The setting key';

COMMENT ON COLUMN unsent_message_property.unsentprop_value IS 'The value of the setting';

ALTER TABLE unsent_message_property ADD CONSTRAINT unsent_fk FOREIGN KEY (unsentprop_unsent_id) REFERENCES unsent_message (unsent_guid);

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('table for linking a service with settings', 'nhily', 'schema/tables/unsentmessageproperty.xml', NOW(), 29, '9:cdf34947606931c9e06fcc2ee789c0ed', 'createTable tableName=unsent_message_property; addForeignKeyConstraint baseTableName=unsent_message_property, constraintName=unsent_fk, referencedTableName=unsent_message', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/unsentmessageproperty.xml::addIndexOnColumnUnsentprop_unsent_id::stihft
CREATE INDEX unsent_message_property_i_1 ON unsent_message_property(unsentprop_unsent_id);

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('addIndexOnColumnUnsentprop_unsent_id', 'stihft', 'schema/tables/unsentmessageproperty.xml', NOW(), 31, '9:6c149ed254ad5787019bdf73a15b3a30', 'createIndex indexName=unsent_message_property_i_1, tableName=unsent_message_property', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/v0.2/exchangelog.xml::Add column containing the MDC request id::stihft
ALTER TABLE log ADD log_mdc_request_id VARCHAR(36);

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('Add column containing the MDC request id', 'stihft', 'schema/tables/v0.2/exchangelog.xml', NOW(), 33, '9:cd02735e35634fe0f0a6e59f7be5a4a0', 'addColumn tableName=log', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/initdata/init_service.xml::service-init01::andtho
INSERT INTO service (serv_id, serv_serviceclassname, serv_name, serv_serviceresponse, serv_desc, serv_active, serv_type, serv_status, serv_updatetime, serv_upuser) VALUES ('00000000-0000-0000-0000-000000000001', 'ManualMovement', 'ManualMovement', 'ManualMovement', 'Handles manual movements', '1', 'OTHER', '1', NOW(), 'UVMS');

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('service-init01', 'andtho', 'schema/initdata/init_service.xml', NOW(), 35, '9:536c6e0cf37b361ee2fb42b639d0d35d', 'insert tableName=service', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset changelog/v0.27/db-changelog_0.27.xml::UNIONVMS-3781::emrinalgr
ALTER TABLE log ADD log_todt VARCHAR(255);

ALTER TABLE log ADD log_to VARCHAR(255);

ALTER TABLE log ADD log_on VARCHAR(255);

ALTER TABLE log ADD log_df VARCHAR(255);

ALTER TABLE log DROP COLUMN duplicate;

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('UNIONVMS-3781', 'emrinalgr', 'changelog/v0.27/db-changelog_0.27.xml', NOW(), 37, '9:08f928ea8cd4a8b0276eafe0047f4ea3', 'addColumn tableName=log; dropColumn columnName=duplicate, tableName=log', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset schema/tables/v0.3/exchange_log_table_changes.xml::Add column containing the MDC request id::stihft
ALTER TABLE log ALTER COLUMN log_senderreceiver TYPE VARCHAR(100) USING (log_senderreceiver::VARCHAR(100));

ALTER TABLE log ALTER COLUMN log_source TYPE VARCHAR(100) USING (log_source::VARCHAR(100));

ALTER TABLE log ALTER COLUMN log_fwdrule TYPE VARCHAR(100) USING (log_fwdrule::VARCHAR(100));

ALTER TABLE log ALTER COLUMN log_recipient TYPE VARCHAR(100) USING (log_recipient::VARCHAR(100));

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('Add column containing the MDC request id', 'stihft', 'schema/tables/v0.3/exchange_log_table_changes.xml', NOW(), 39, '9:2bce631c85f434fed81ff78613fb0f0e', 'modifyDataType columnName=log_senderreceiver, tableName=log; modifyDataType columnName=log_source, tableName=log; modifyDataType columnName=log_fwdrule, tableName=log; modifyDataType columnName=log_recipient, tableName=log', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset changelog/v4.0.31/db-changelog_1.xml::UNIONVMS-4014::emrinalgr
ALTER TABLE log ADD log_business_error TEXT;

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('UNIONVMS-4014', 'emrinalgr', 'changelog/v4.0.31/db-changelog_1.xml', NOW(), 41, '9:636232ac7da59ac9d1857689d8cabe33', 'addColumn tableName=log', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset changelog/v5.2.13/db-changelog_add_index_to_log_type_ref_guid.xml::db-changelog_add_index_to_log_type_ref_guid::joemat
CREATE INDEX log_log_type_ref_guid_idx ON log(log_type_ref_guid);

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('db-changelog_add_index_to_log_type_ref_guid', 'joemat', 'changelog/v5.2.13/db-changelog_add_index_to_log_type_ref_guid.xml', NOW(), 43, '9:ee7f58811715cc34f64dc265e6b46490', 'createIndex indexName=log_log_type_ref_guid_idx, tableName=log', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset changelog/v5.3.8/db-changelog_add_additional_ref_to_log.xml.xml::db-changelog_add_additional_ref_to_log.xml::peerik
ALTER TABLE log ADD log_related_ref_guid UUID;

ALTER TABLE log ADD log_related_ref_type VARCHAR(25);

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('db-changelog_add_additional_ref_to_log.xml', 'peerik', 'changelog/v5.3.8/db-changelog_add_additional_ref_to_log.xml.xml', NOW(), 45, '9:bb0c3be6dac407ea5c044f0f7740ea9f', 'addColumn tableName=log; addColumn tableName=log', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset changelog/v5.3.8/db-changelog_add_unsent_message_resend_parameter.xml::add_unsent_message_resend_parameter::peerik
INSERT INTO parameter (param_description, param_id, param_value) VALUES ('Minutes until unsent messages are retried. Disabled = 0', 'UNSENT_MESSAGE_THRESHOLD', '0');

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('add_unsent_message_resend_parameter', 'peerik', 'changelog/v5.3.8/db-changelog_add_unsent_message_resend_parameter.xml', NOW(), 47, '9:d792ea5046499228e5b229bb4447ef4f', 'insert tableName=parameter', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset changelog/v5.3.27/db-changelog_add_unsent_message_acknowledged.xml::add_unsent_message_acknowledged::peerik
ALTER TABLE unsent_message ADD unsent_acknowledged BOOLEAN DEFAULT FALSE;

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('add_unsent_message_acknowledged', 'peerik', 'changelog/v5.3.27/db-changelog_add_unsent_message_acknowledged.xml', NOW(), 49, '9:818de3e8b853bab8a72cf8e54fb03971', 'addColumn tableName=unsent_message', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

-- Changeset changelog/v5.2.32/db-changelog_add_log_index_log_daterecieved.xml::Add index on log_daterecieved::johwal
CREATE INDEX log_log_daterecieved_idx ON log(log_daterecieved);

INSERT INTO databasechangelog (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, DESCRIPTION, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('Add index on log_daterecieved', 'johwal', 'changelog/v5.2.32/db-changelog_add_log_index_log_daterecieved.xml', NOW(), 51, '9:173d1ec8823384f7336e2d9b3d076c19', 'createIndex indexName=log_log_daterecieved_idx, tableName=log', '', 'EXECUTED', NULL, NULL, '4.29.1', '5521009775');

